@@ -37,8 +37,16 @@ pub trait BaseFmt {
     fn write_title(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
     fn write_xname(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
     fn write_yname(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
-    fn write_xwher(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
-    fn write_ywher(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_xwher(
+        &mut self,
+        writer: &mut dyn fmt::Write,
+        ind: crate::ticks::IndexRequester,
+    ) -> fmt::Result;
+    fn write_ywher(
+        &mut self,
+        writer: &mut dyn fmt::Write,
+        ind: crate::ticks::IndexRequester,
+    ) -> fmt::Result;
     fn write_xtick(&mut self, writer: &mut dyn fmt::Write, val: &Self::X) -> fmt::Result;
     fn write_ytick(&mut self, writer: &mut dyn fmt::Write, val: &Self::Y) -> fmt::Result;
 
